from django.shortcuts import render, redirect
from django.contrib import messages
from django.contrib.auth.models import User,auth
from teacherapp.models import StudentLectures
from django.contrib.auth.decorators import login_required
from .forms import StudentLecturesForm
from django.core.paginator import Paginator

# Create your views here.

# Create your views here.

@login_required(login_url='login')
def student_dashboard(request):
        '''
                Teachers dashboard 
        '''
        url = 'teacherapp/index.html'
        notice = StudentLectures.objects.all().order_by('-created_on')[:7]
        return render(request, url, {'notice':notice})



@login_required(login_url='login')
def lectures_list(request):
        url = 'studentapp/student_lectures.html'
        lectures = StudentLectures.objects.all().order_by('-created_on')
        paginate = Paginator(lectures, 10)
        page_num = request.GET.get('page')
        lectures = paginate.get_page(page_num)
        return render(request, url, {'lecture': lectures})


@login_required(login_url='login')
def lecture_display(request, lecture_id):
        '''
                Lecture Page where a student can play and watch lecture
        '''
        url = 'studentapp/lecture_display.html'
        lecture = int(lecture_id)
        lecture_link = StudentLectures.objects.get(id=lecture)
        return render(request, url, {'lecture': lecture_link})



def subject_lectures(request, subject_id):
        '''
                To get all subject lecture on behalf of subject names foreignkey used
                filtered lectures by subject
        '''
        url = 'studentapp/subject_lectures.html'
        subject = int(subject_id)
        
        try:
                lectures = StudentLectures.objects.filter(lecture_subject=subject).order_by('-created_on')
                paginate = Paginator(lectures, 10)
                page_num = request.GET.get('page')
                lectures = paginate.get_page(page_num)
        except Exception as e:
                messages.warning(request, f'Error {e}')
                return redirect('teacherapp:students')
        finally:
                return render(request, url, {'lectures': lectures})